# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: drivers.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2
from . import options_pb2 as options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='drivers.proto',
  package='v1',
  syntax='proto3',
  serialized_options=_b('\n\034com.strongdm.api.v1.plumbingB\017DriversPlumbing'),
  serialized_pb=_b('\n\rdrivers.proto\x12\x02v1\x1a,protoc-gen-swagger/options/annotations.proto\x1a\roptions.proto\"\xac\x0e\n\x08Resource\x12\x1c\n\x06\x61thena\x18\x64 \x01(\x0b\x32\n.v1.AthenaH\x00\x12\"\n\tbig_query\x18\xc8\x01 \x01(\x0b\x32\x0c.v1.BigQueryH\x00\x12#\n\tcassandra\x18\xac\x02 \x01(\x0b\x32\r.v1.CassandraH\x00\x12\x1b\n\x05\x64ruid\x18\x90\x03 \x01(\x0b\x32\t.v1.DruidH\x00\x12\"\n\tdynamo_db\x18\xf4\x03 \x01(\x0b\x32\x0c.v1.DynamoDBH\x00\x12\"\n\tamazon_es\x18\xd8\x04 \x01(\x0b\x32\x0c.v1.AmazonESH\x00\x12\x1f\n\x07\x65lastic\x18\xd9\x04 \x01(\x0b\x32\x0b.v1.ElasticH\x00\x12-\n\x0fhttp_basic_auth\x18\xbc\x05 \x01(\x0b\x32\x11.v1.HTTPBasicAuthH\x00\x12\'\n\x0chttp_no_auth\x18\xbd\x05 \x01(\x0b\x32\x0e.v1.HTTPNoAuthH\x00\x12\"\n\thttp_auth\x18\xbe\x05 \x01(\x0b\x32\x0c.v1.HTTPAuthH\x00\x12%\n\nkubernetes\x18\xa0\x06 \x01(\x0b\x32\x0e.v1.KubernetesH\x00\x12\x39\n\x15kubernetes_basic_auth\x18\xa1\x06 \x01(\x0b\x32\x17.v1.KubernetesBasicAuthH\x00\x12\x43\n\x1akubernetes_service_account\x18\xa4\x06 \x01(\x0b\x32\x1c.v1.KubernetesServiceAccountH\x00\x12$\n\namazon_eks\x18\xa2\x06 \x01(\x0b\x32\r.v1.AmazonEKSH\x00\x12$\n\ngoogle_gke\x18\xa3\x06 \x01(\x0b\x32\r.v1.GoogleGKEH\x00\x12\x17\n\x03\x61ks\x18\xa5\x06 \x01(\x0b\x32\x07.v1.AKSH\x00\x12+\n\x0e\x61ks_basic_auth\x18\xa6\x06 \x01(\x0b\x32\x10.v1.AKSBasicAuthH\x00\x12\x35\n\x13\x61ks_service_account\x18\xa7\x06 \x01(\x0b\x32\x15.v1.AKSServiceAccountH\x00\x12#\n\tmemcached\x18\x84\x07 \x01(\x0b\x32\r.v1.MemcachedH\x00\x12\x31\n\x11mongo_legacy_host\x18\xe8\x07 \x01(\x0b\x32\x13.v1.MongoLegacyHostH\x00\x12=\n\x17mongo_legacy_replicaset\x18\xe9\x07 \x01(\x0b\x32\x19.v1.MongoLegacyReplicasetH\x00\x12$\n\nmongo_host\x18\xea\x07 \x01(\x0b\x32\r.v1.MongoHostH\x00\x12\x31\n\x11mongo_replica_set\x18\xeb\x07 \x01(\x0b\x32\x13.v1.MongoReplicaSetH\x00\x12\x1b\n\x05mysql\x18\xcc\x08 \x01(\x0b\x32\t.v1.MysqlH\x00\x12(\n\x0c\x61urora_mysql\x18\xcd\x08 \x01(\x0b\x32\x0f.v1.AuroraMysqlH\x00\x12!\n\x08\x63lustrix\x18\xce\x08 \x01(\x0b\x32\x0c.v1.ClustrixH\x00\x12\x1b\n\x05maria\x18\xcf\x08 \x01(\x0b\x32\t.v1.MariaH\x00\x12\x1d\n\x06memsql\x18\xd0\x08 \x01(\x0b\x32\n.v1.MemsqlH\x00\x12\x1d\n\x06oracle\x18\xb0\t \x01(\x0b\x32\n.v1.OracleH\x00\x12!\n\x08postgres\x18\x94\n \x01(\x0b\x32\x0c.v1.PostgresH\x00\x12.\n\x0f\x61urora_postgres\x18\x95\n \x01(\x0b\x32\x12.v1.AuroraPostgresH\x00\x12#\n\tgreenplum\x18\x96\n \x01(\x0b\x32\r.v1.GreenplumH\x00\x12#\n\tcockroach\x18\x97\n \x01(\x0b\x32\r.v1.CockroachH\x00\x12!\n\x08redshift\x18\x98\n \x01(\x0b\x32\x0c.v1.RedshiftH\x00\x12\x1d\n\x06presto\x18\xf8\n \x01(\x0b\x32\n.v1.PrestoH\x00\x12\x17\n\x03rdp\x18\xdc\x0b \x01(\x0b\x32\x07.v1.RDPH\x00\x12\x1b\n\x05redis\x18\xc0\x0c \x01(\x0b\x32\t.v1.RedisH\x00\x12\x32\n\x11\x65lasticache_redis\x18\xc1\x0c \x01(\x0b\x32\x14.v1.ElasticacheRedisH\x00\x12#\n\tsnowflake\x18\xa4\r \x01(\x0b\x32\r.v1.SnowflakeH\x00\x12$\n\nsql_server\x18\x88\x0e \x01(\x0b\x32\r.v1.SQLServerH\x00\x12\x17\n\x03ssh\x18\xec\x0e \x01(\x0b\x32\x07.v1.SSHH\x00\x12\x1d\n\x06sybase\x18\xd0\x0f \x01(\x0b\x32\n.v1.SybaseH\x00\x12\"\n\tsybase_iq\x18\xd1\x0f \x01(\x0b\x32\x0c.v1.SybaseIQH\x00\x12!\n\x08teradata\x18\xb4\x10 \x01(\x0b\x32\x0c.v1.TeradataH\x00:c\xfa\xf8\xb3\x07T\xc2\xf3\xb3\x07O\xa2\xf3\xb3\x07!tf_examples/resource_resource.txt\xaa\xf3\xb3\x07$tf_examples/resource_data_source.txt\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42\x1a\n\x08resource\x12\x0e\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04name\"\xa5\x03\n\x06\x41thena\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x37\n\naccess_key\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12>\n\x11secret_access_key\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x33\n\x06output\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x04 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x41\n\x06region\x18\x05 \x01(\tB1\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x0b:\tus-east-1\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x94\x03\n\x08\x42igQuery\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x38\n\x0bprivate_key\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x34\n\x07project\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x03 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x65ndpoint\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd3\x03\n\tCassandra\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x04 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x05 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x39\x30\x34\x32\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\x06 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x94\x03\n\x05\x44ruid\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x02 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x05 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x38\x30\x38\x32\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x9b\x03\n\x08\x44ynamoDB\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x37\n\naccess_key\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12>\n\x11secret_access_key\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x33\n\x06region\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x65ndpoint\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x9b\x03\n\x08\x41mazonES\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x33\n\x06region\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12>\n\x11secret_access_key\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x65ndpoint\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x37\n\naccess_key\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd1\x03\n\x07\x45lastic\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x04 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x05 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x39\x32\x30\x30\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\x06 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x97\x04\n\rHTTPBasicAuth\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x30\n\x03url\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x43\n\x10healthcheck_path\x18\x02 \x01(\tB)\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x03:\x01/\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12>\n\x11headers_blacklist\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x0c\x64\x65\x66\x61ult_path\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x36\n\tsubdomain\x18\x07 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xa6\x03\n\nHTTPNoAuth\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x30\n\x03url\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x43\n\x10healthcheck_path\x18\x02 \x01(\tB)\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x03:\x01/\x92\x41\x02@\x00\x12>\n\x11headers_blacklist\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x0c\x64\x65\x66\x61ult_path\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x36\n\tsubdomain\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xde\x03\n\x08HTTPAuth\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x30\n\x03url\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x43\n\x10healthcheck_path\x18\x02 \x01(\tB)\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x03:\x01/\x92\x41\x02@\x00\x12\x38\n\x0b\x61uth_header\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12>\n\x11headers_blacklist\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x0c\x64\x65\x66\x61ult_path\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x36\n\tsubdomain\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x85\x05\n\nKubernetes\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x04port\x18\x02 \x01(\x05\x42+\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x05:\x03\x34\x34\x33\x92\x41\x02@\x00\x12\x42\n\x15\x63\x65rtificate_authority\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12K\n\x1e\x63\x65rtificate_authority_filename\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12?\n\x12\x63lient_certificate\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12H\n\x1b\x63lient_certificate_filename\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x37\n\nclient_key\x18\x07 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12@\n\x13\x63lient_key_filename\x18\x08 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe5\x02\n\x13KubernetesBasicAuth\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x04port\x18\x02 \x01(\x05\x42+\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x05:\x03\x34\x34\x33\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb0\x02\n\x18KubernetesServiceAccount\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x04port\x18\x02 \x01(\x05\x42+\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x05:\x03\x34\x34\x33\x92\x41\x02@\x00\x12\x32\n\x05token\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe3\x04\n\tAmazonEKS\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08\x65ndpoint\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x37\n\naccess_key\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12>\n\x11secret_access_key\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x42\n\x15\x63\x65rtificate_authority\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12K\n\x1e\x63\x65rtificate_authority_filename\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x33\n\x06region\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x0c\x63luster_name\x18\x07 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08role_arn\x18\x08 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd0\x03\n\tGoogleGKE\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08\x65ndpoint\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x42\n\x15\x63\x65rtificate_authority\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12K\n\x1e\x63\x65rtificate_authority_filename\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12@\n\x13service_account_key\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12I\n\x1cservice_account_key_filename\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xfe\x04\n\x03\x41KS\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x04port\x18\x02 \x01(\x05\x42+\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x05:\x03\x34\x34\x33\x92\x41\x02@\x00\x12\x42\n\x15\x63\x65rtificate_authority\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12K\n\x1e\x63\x65rtificate_authority_filename\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12?\n\x12\x63lient_certificate\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12H\n\x1b\x63lient_certificate_filename\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x37\n\nclient_key\x18\x07 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12@\n\x13\x63lient_key_filename\x18\x08 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xde\x02\n\x0c\x41KSBasicAuth\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x04port\x18\x02 \x01(\x05\x42+\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x05:\x03\x34\x34\x33\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xa9\x02\n\x11\x41KSServiceAccount\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x04port\x18\x02 \x01(\x05\x42+\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x05:\x03\x34\x34\x33\x92\x41\x02@\x00\x12\x32\n\x05token\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xab\x02\n\tMemcached\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x02 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12;\n\x04port\x18\x03 \x01(\x05\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x31\x31\x32\x31\x31\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd0\x04\n\x0fMongoLegacyHost\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rauth_database\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x03 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12;\n\x04port\x18\x06 \x01(\x05\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x32\x37\x30\x31\x37\x92\x41\x02@\x00\x12\x38\n\x0breplica_set\x18\x07 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\x08 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xa1\x05\n\x15MongoLegacyReplicaset\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rauth_database\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x03 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12;\n\x04port\x18\x06 \x01(\x05\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x32\x37\x30\x31\x37\x92\x41\x02@\x00\x12\x38\n\x0breplica_set\x18\x07 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12I\n\x12\x63onnect_to_replica\x18\x08 \x01(\x08\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x66\x61lse\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\t \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x90\x04\n\tMongoHost\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rauth_database\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x03 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12;\n\x04port\x18\x06 \x01(\x05\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x32\x37\x30\x31\x37\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\x08 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x9b\x05\n\x0fMongoReplicaSet\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rauth_database\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x03 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12;\n\x04port\x18\x06 \x01(\x05\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x32\x37\x30\x31\x37\x92\x41\x02@\x00\x12\x38\n\x0breplica_set\x18\x07 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12I\n\x12\x63onnect_to_replica\x18\x08 \x01(\x08\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x66\x61lse\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\t \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xcb\x03\n\x05Mysql\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x33\x33\x30\x36\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd1\x03\n\x0b\x41uroraMysql\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x33\x33\x30\x36\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xce\x03\n\x08\x43lustrix\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x33\x33\x30\x36\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xcb\x03\n\x05Maria\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x33\x33\x30\x36\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xcc\x03\n\x06Memsql\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x33\x33\x30\x36\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x87\x04\n\x06Oracle\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x05 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x31\x35\x32\x31\x92\x41\x02@\x00\x12:\n\rport_override\x18\x06 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\x07 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x8e\x04\n\x08Postgres\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x35\x34\x33\x32\x92\x41\x02@\x00\x12>\n\x11override_database\x18\x07 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x94\x04\n\x0e\x41uroraPostgres\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x35\x34\x33\x32\x92\x41\x02@\x00\x12>\n\x11override_database\x18\x07 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x8f\x04\n\tGreenplum\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x35\x34\x33\x32\x92\x41\x02@\x00\x12>\n\x11override_database\x18\x07 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x8f\x04\n\tCockroach\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x35\x34\x33\x32\x92\x41\x02@\x00\x12>\n\x11override_database\x18\x07 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x8e\x04\n\x08Redshift\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x06 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x35\x34\x33\x39\x92\x41\x02@\x00\x12>\n\x11override_database\x18\x07 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x87\x04\n\x06Presto\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x04 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x05 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x38\x30\x38\x30\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x39\n\x0ctls_required\x18\x07 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x92\x03\n\x03RDP\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x04 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x05 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x33\x33\x38\x39\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xdd\x02\n\x05Redis\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x02 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x04 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x36\x33\x37\x39\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xac\x03\n\x10\x45lasticacheRedis\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x02 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x04 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x36\x33\x37\x39\x92\x41\x02@\x00\x12\x42\n\x0ctls_required\x18\x05 \x01(\x08\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04true\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xc8\x03\n\tSnowflake\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x33\n\x06schema\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x06 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xc4\x04\n\tSQLServer\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08\x64\x61tabase\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x05 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x33\n\x06schema\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x07 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x31\x34\x33\x33\x92\x41\x02@\x00\x12>\n\x11override_database\x18\x08 \x01(\x08\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x9e\x03\n\x03SSH\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x38\n\x04port\x18\x03 \x01(\x05\x42*\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x04:\x02\x32\x32\x92\x41\x02@\x00\x12\x37\n\npublic_key\x18\x04 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x46\n\x0fport_forwarding\x18\x05 \x01(\x08\x42-\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x07:\x05\x66\x61lse\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x95\x03\n\x06Sybase\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x03 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x04 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x32\x36\x33\x38\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x97\x03\n\x08SybaseIQ\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x03 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x04 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x32\x36\x33\x38\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x97\x03\n\x08Teradata\x12\x18\n\x02id\x18\x80\x80\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x04name\x18\x81\x80\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\x12\"\n\x07healthy\x18\x82\x80\x02 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x92\x41\x02@\x01\x12\x35\n\x08hostname\x18\x01 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08username\x18\x02 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12\x35\n\x08password\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\rport_override\x18\x04 \x01(\x05\x42#\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x02@\x00\x12:\n\x04port\x18\x05 \x01(\x05\x42,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x05\xc0\xf3\xb3\x07\x00\xf2\xf8\xb3\x07\x05\xd8\xf3\xb3\x07\x00\x92\x41\x06:\x04\x31\x30\x32\x35\x92\x41\x02@\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42/\n\x1c\x63om.strongdm.api.v1.plumbingB\x0f\x44riversPlumbingb\x06proto3')
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,options__pb2.DESCRIPTOR,])




_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='v1.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='athena', full_name='v1.Resource.athena', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='big_query', full_name='v1.Resource.big_query', index=1,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cassandra', full_name='v1.Resource.cassandra', index=2,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='druid', full_name='v1.Resource.druid', index=3,
      number=400, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamo_db', full_name='v1.Resource.dynamo_db', index=4,
      number=500, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amazon_es', full_name='v1.Resource.amazon_es', index=5,
      number=600, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elastic', full_name='v1.Resource.elastic', index=6,
      number=601, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_basic_auth', full_name='v1.Resource.http_basic_auth', index=7,
      number=700, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_no_auth', full_name='v1.Resource.http_no_auth', index=8,
      number=701, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_auth', full_name='v1.Resource.http_auth', index=9,
      number=702, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kubernetes', full_name='v1.Resource.kubernetes', index=10,
      number=800, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kubernetes_basic_auth', full_name='v1.Resource.kubernetes_basic_auth', index=11,
      number=801, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kubernetes_service_account', full_name='v1.Resource.kubernetes_service_account', index=12,
      number=804, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amazon_eks', full_name='v1.Resource.amazon_eks', index=13,
      number=802, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='google_gke', full_name='v1.Resource.google_gke', index=14,
      number=803, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aks', full_name='v1.Resource.aks', index=15,
      number=805, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aks_basic_auth', full_name='v1.Resource.aks_basic_auth', index=16,
      number=806, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aks_service_account', full_name='v1.Resource.aks_service_account', index=17,
      number=807, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memcached', full_name='v1.Resource.memcached', index=18,
      number=900, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mongo_legacy_host', full_name='v1.Resource.mongo_legacy_host', index=19,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mongo_legacy_replicaset', full_name='v1.Resource.mongo_legacy_replicaset', index=20,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mongo_host', full_name='v1.Resource.mongo_host', index=21,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mongo_replica_set', full_name='v1.Resource.mongo_replica_set', index=22,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mysql', full_name='v1.Resource.mysql', index=23,
      number=1100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aurora_mysql', full_name='v1.Resource.aurora_mysql', index=24,
      number=1101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clustrix', full_name='v1.Resource.clustrix', index=25,
      number=1102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maria', full_name='v1.Resource.maria', index=26,
      number=1103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memsql', full_name='v1.Resource.memsql', index=27,
      number=1104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oracle', full_name='v1.Resource.oracle', index=28,
      number=1200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postgres', full_name='v1.Resource.postgres', index=29,
      number=1300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aurora_postgres', full_name='v1.Resource.aurora_postgres', index=30,
      number=1301, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='greenplum', full_name='v1.Resource.greenplum', index=31,
      number=1302, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cockroach', full_name='v1.Resource.cockroach', index=32,
      number=1303, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redshift', full_name='v1.Resource.redshift', index=33,
      number=1304, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='presto', full_name='v1.Resource.presto', index=34,
      number=1400, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rdp', full_name='v1.Resource.rdp', index=35,
      number=1500, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redis', full_name='v1.Resource.redis', index=36,
      number=1600, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elasticache_redis', full_name='v1.Resource.elasticache_redis', index=37,
      number=1601, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snowflake', full_name='v1.Resource.snowflake', index=38,
      number=1700, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sql_server', full_name='v1.Resource.sql_server', index=39,
      number=1800, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ssh', full_name='v1.Resource.ssh', index=40,
      number=1900, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sybase', full_name='v1.Resource.sybase', index=41,
      number=2000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sybase_iq', full_name='v1.Resource.sybase_iq', index=42,
      number=2001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teradata', full_name='v1.Resource.teradata', index=43,
      number=2100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007T\302\363\263\007O\242\363\263\007!tf_examples/resource_resource.txt\252\363\263\007$tf_examples/resource_data_source.txt\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='resource', full_name='v1.Resource.resource',
      index=0, containing_type=None, fields=[], serialized_options=_b('\252\370\263\007\t\252\370\263\007\004name')),
  ],
  serialized_start=83,
  serialized_end=1919,
)


_ATHENA = _descriptor.Descriptor(
  name='Athena',
  full_name='v1.Athena',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Athena.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Athena.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Athena.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_key', full_name='v1.Athena.access_key', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret_access_key', full_name='v1.Athena.secret_access_key', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='v1.Athena.output', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Athena.port_override', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='v1.Athena.region', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\013:\tus-east-1\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1922,
  serialized_end=2343,
)


_BIGQUERY = _descriptor.Descriptor(
  name='BigQuery',
  full_name='v1.BigQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.BigQuery.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.BigQuery.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.BigQuery.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='v1.BigQuery.private_key', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='v1.BigQuery.project', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.BigQuery.port_override', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='v1.BigQuery.endpoint', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.BigQuery.username', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2346,
  serialized_end=2750,
)


_CASSANDRA = _descriptor.Descriptor(
  name='Cassandra',
  full_name='v1.Cassandra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Cassandra.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Cassandra.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Cassandra.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Cassandra.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Cassandra.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Cassandra.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Cassandra.port_override', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Cassandra.port', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0049042\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.Cassandra.tls_required', index=8,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2753,
  serialized_end=3220,
)


_DRUID = _descriptor.Descriptor(
  name='Druid',
  full_name='v1.Druid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Druid.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Druid.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Druid.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Druid.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Druid.port_override', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Druid.username', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Druid.password', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Druid.port', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0048082\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3223,
  serialized_end=3627,
)


_DYNAMODB = _descriptor.Descriptor(
  name='DynamoDB',
  full_name='v1.DynamoDB',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.DynamoDB.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.DynamoDB.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.DynamoDB.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_key', full_name='v1.DynamoDB.access_key', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret_access_key', full_name='v1.DynamoDB.secret_access_key', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='v1.DynamoDB.region', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='v1.DynamoDB.endpoint', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.DynamoDB.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3630,
  serialized_end=4041,
)


_AMAZONES = _descriptor.Descriptor(
  name='AmazonES',
  full_name='v1.AmazonES',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AmazonES.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.AmazonES.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.AmazonES.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='v1.AmazonES.region', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret_access_key', full_name='v1.AmazonES.secret_access_key', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='v1.AmazonES.endpoint', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_key', full_name='v1.AmazonES.access_key', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.AmazonES.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4044,
  serialized_end=4455,
)


_ELASTIC = _descriptor.Descriptor(
  name='Elastic',
  full_name='v1.Elastic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Elastic.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Elastic.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Elastic.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Elastic.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Elastic.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Elastic.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Elastic.port_override', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Elastic.port', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0049200\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.Elastic.tls_required', index=8,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4458,
  serialized_end=4923,
)


_HTTPBASICAUTH = _descriptor.Descriptor(
  name='HTTPBasicAuth',
  full_name='v1.HTTPBasicAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.HTTPBasicAuth.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.HTTPBasicAuth.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.HTTPBasicAuth.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='v1.HTTPBasicAuth.url', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthcheck_path', full_name='v1.HTTPBasicAuth.healthcheck_path', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\003:\001/\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.HTTPBasicAuth.username', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.HTTPBasicAuth.password', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headers_blacklist', full_name='v1.HTTPBasicAuth.headers_blacklist', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_path', full_name='v1.HTTPBasicAuth.default_path', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subdomain', full_name='v1.HTTPBasicAuth.subdomain', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4926,
  serialized_end=5461,
)


_HTTPNOAUTH = _descriptor.Descriptor(
  name='HTTPNoAuth',
  full_name='v1.HTTPNoAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.HTTPNoAuth.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.HTTPNoAuth.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.HTTPNoAuth.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='v1.HTTPNoAuth.url', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthcheck_path', full_name='v1.HTTPNoAuth.healthcheck_path', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\003:\001/\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headers_blacklist', full_name='v1.HTTPNoAuth.headers_blacklist', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_path', full_name='v1.HTTPNoAuth.default_path', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subdomain', full_name='v1.HTTPNoAuth.subdomain', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5464,
  serialized_end=5886,
)


_HTTPAUTH = _descriptor.Descriptor(
  name='HTTPAuth',
  full_name='v1.HTTPAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.HTTPAuth.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.HTTPAuth.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.HTTPAuth.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='v1.HTTPAuth.url', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthcheck_path', full_name='v1.HTTPAuth.healthcheck_path', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\003:\001/\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_header', full_name='v1.HTTPAuth.auth_header', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headers_blacklist', full_name='v1.HTTPAuth.headers_blacklist', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_path', full_name='v1.HTTPAuth.default_path', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subdomain', full_name='v1.HTTPAuth.subdomain', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5889,
  serialized_end=6367,
)


_KUBERNETES = _descriptor.Descriptor(
  name='Kubernetes',
  full_name='v1.Kubernetes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Kubernetes.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Kubernetes.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Kubernetes.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Kubernetes.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Kubernetes.port', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\005:\003443\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority', full_name='v1.Kubernetes.certificate_authority', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority_filename', full_name='v1.Kubernetes.certificate_authority_filename', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_certificate', full_name='v1.Kubernetes.client_certificate', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_certificate_filename', full_name='v1.Kubernetes.client_certificate_filename', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_key', full_name='v1.Kubernetes.client_key', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_key_filename', full_name='v1.Kubernetes.client_key_filename', index=10,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6370,
  serialized_end=7015,
)


_KUBERNETESBASICAUTH = _descriptor.Descriptor(
  name='KubernetesBasicAuth',
  full_name='v1.KubernetesBasicAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.KubernetesBasicAuth.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.KubernetesBasicAuth.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.KubernetesBasicAuth.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.KubernetesBasicAuth.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.KubernetesBasicAuth.port', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\005:\003443\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.KubernetesBasicAuth.username', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.KubernetesBasicAuth.password', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7018,
  serialized_end=7375,
)


_KUBERNETESSERVICEACCOUNT = _descriptor.Descriptor(
  name='KubernetesServiceAccount',
  full_name='v1.KubernetesServiceAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.KubernetesServiceAccount.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.KubernetesServiceAccount.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.KubernetesServiceAccount.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.KubernetesServiceAccount.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.KubernetesServiceAccount.port', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\005:\003443\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='v1.KubernetesServiceAccount.token', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7378,
  serialized_end=7682,
)


_AMAZONEKS = _descriptor.Descriptor(
  name='AmazonEKS',
  full_name='v1.AmazonEKS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AmazonEKS.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.AmazonEKS.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.AmazonEKS.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='v1.AmazonEKS.endpoint', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_key', full_name='v1.AmazonEKS.access_key', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret_access_key', full_name='v1.AmazonEKS.secret_access_key', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority', full_name='v1.AmazonEKS.certificate_authority', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority_filename', full_name='v1.AmazonEKS.certificate_authority_filename', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='v1.AmazonEKS.region', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='v1.AmazonEKS.cluster_name', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_arn', full_name='v1.AmazonEKS.role_arn', index=10,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7685,
  serialized_end=8296,
)


_GOOGLEGKE = _descriptor.Descriptor(
  name='GoogleGKE',
  full_name='v1.GoogleGKE',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.GoogleGKE.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.GoogleGKE.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.GoogleGKE.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='v1.GoogleGKE.endpoint', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority', full_name='v1.GoogleGKE.certificate_authority', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority_filename', full_name='v1.GoogleGKE.certificate_authority_filename', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_account_key', full_name='v1.GoogleGKE.service_account_key', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_account_key_filename', full_name='v1.GoogleGKE.service_account_key_filename', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8299,
  serialized_end=8763,
)


_AKS = _descriptor.Descriptor(
  name='AKS',
  full_name='v1.AKS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AKS.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.AKS.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.AKS.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.AKS.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.AKS.port', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\005:\003443\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority', full_name='v1.AKS.certificate_authority', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_authority_filename', full_name='v1.AKS.certificate_authority_filename', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_certificate', full_name='v1.AKS.client_certificate', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_certificate_filename', full_name='v1.AKS.client_certificate_filename', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_key', full_name='v1.AKS.client_key', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_key_filename', full_name='v1.AKS.client_key_filename', index=10,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8766,
  serialized_end=9404,
)


_AKSBASICAUTH = _descriptor.Descriptor(
  name='AKSBasicAuth',
  full_name='v1.AKSBasicAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AKSBasicAuth.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.AKSBasicAuth.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.AKSBasicAuth.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.AKSBasicAuth.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.AKSBasicAuth.port', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\005:\003443\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.AKSBasicAuth.username', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.AKSBasicAuth.password', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9407,
  serialized_end=9757,
)


_AKSSERVICEACCOUNT = _descriptor.Descriptor(
  name='AKSServiceAccount',
  full_name='v1.AKSServiceAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AKSServiceAccount.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.AKSServiceAccount.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.AKSServiceAccount.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.AKSServiceAccount.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.AKSServiceAccount.port', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\005:\003443\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='v1.AKSServiceAccount.token', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9760,
  serialized_end=10057,
)


_MEMCACHED = _descriptor.Descriptor(
  name='Memcached',
  full_name='v1.Memcached',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Memcached.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Memcached.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Memcached.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Memcached.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Memcached.port_override', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Memcached.port', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\00511211\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10060,
  serialized_end=10359,
)


_MONGOLEGACYHOST = _descriptor.Descriptor(
  name='MongoLegacyHost',
  full_name='v1.MongoLegacyHost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.MongoLegacyHost.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.MongoLegacyHost.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.MongoLegacyHost.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.MongoLegacyHost.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_database', full_name='v1.MongoLegacyHost.auth_database', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.MongoLegacyHost.port_override', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.MongoLegacyHost.username', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.MongoLegacyHost.password', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.MongoLegacyHost.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\00527017\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replica_set', full_name='v1.MongoLegacyHost.replica_set', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.MongoLegacyHost.tls_required', index=10,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10362,
  serialized_end=10954,
)


_MONGOLEGACYREPLICASET = _descriptor.Descriptor(
  name='MongoLegacyReplicaset',
  full_name='v1.MongoLegacyReplicaset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.MongoLegacyReplicaset.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.MongoLegacyReplicaset.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.MongoLegacyReplicaset.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.MongoLegacyReplicaset.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_database', full_name='v1.MongoLegacyReplicaset.auth_database', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.MongoLegacyReplicaset.port_override', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.MongoLegacyReplicaset.username', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.MongoLegacyReplicaset.password', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.MongoLegacyReplicaset.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\00527017\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replica_set', full_name='v1.MongoLegacyReplicaset.replica_set', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connect_to_replica', full_name='v1.MongoLegacyReplicaset.connect_to_replica', index=10,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\005false\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.MongoLegacyReplicaset.tls_required', index=11,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10957,
  serialized_end=11630,
)


_MONGOHOST = _descriptor.Descriptor(
  name='MongoHost',
  full_name='v1.MongoHost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.MongoHost.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.MongoHost.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.MongoHost.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.MongoHost.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_database', full_name='v1.MongoHost.auth_database', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.MongoHost.port_override', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.MongoHost.username', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.MongoHost.password', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.MongoHost.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\00527017\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.MongoHost.tls_required', index=9,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11633,
  serialized_end=12161,
)


_MONGOREPLICASET = _descriptor.Descriptor(
  name='MongoReplicaSet',
  full_name='v1.MongoReplicaSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.MongoReplicaSet.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.MongoReplicaSet.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.MongoReplicaSet.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.MongoReplicaSet.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_database', full_name='v1.MongoReplicaSet.auth_database', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.MongoReplicaSet.port_override', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.MongoReplicaSet.username', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.MongoReplicaSet.password', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.MongoReplicaSet.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\00527017\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replica_set', full_name='v1.MongoReplicaSet.replica_set', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connect_to_replica', full_name='v1.MongoReplicaSet.connect_to_replica', index=10,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\005false\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.MongoReplicaSet.tls_required', index=11,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12164,
  serialized_end=12831,
)


_MYSQL = _descriptor.Descriptor(
  name='Mysql',
  full_name='v1.Mysql',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Mysql.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Mysql.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Mysql.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Mysql.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Mysql.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Mysql.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Mysql.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Mysql.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Mysql.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0043306\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12834,
  serialized_end=13293,
)


_AURORAMYSQL = _descriptor.Descriptor(
  name='AuroraMysql',
  full_name='v1.AuroraMysql',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AuroraMysql.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.AuroraMysql.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.AuroraMysql.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.AuroraMysql.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.AuroraMysql.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.AuroraMysql.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.AuroraMysql.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.AuroraMysql.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.AuroraMysql.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0043306\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13296,
  serialized_end=13761,
)


_CLUSTRIX = _descriptor.Descriptor(
  name='Clustrix',
  full_name='v1.Clustrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Clustrix.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Clustrix.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Clustrix.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Clustrix.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Clustrix.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Clustrix.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Clustrix.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Clustrix.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Clustrix.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0043306\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13764,
  serialized_end=14226,
)


_MARIA = _descriptor.Descriptor(
  name='Maria',
  full_name='v1.Maria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Maria.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Maria.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Maria.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Maria.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Maria.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Maria.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Maria.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Maria.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Maria.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0043306\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14229,
  serialized_end=14688,
)


_MEMSQL = _descriptor.Descriptor(
  name='Memsql',
  full_name='v1.Memsql',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Memsql.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Memsql.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Memsql.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Memsql.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Memsql.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Memsql.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Memsql.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Memsql.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Memsql.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0043306\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14691,
  serialized_end=15151,
)


_ORACLE = _descriptor.Descriptor(
  name='Oracle',
  full_name='v1.Oracle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Oracle.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Oracle.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Oracle.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Oracle.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Oracle.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Oracle.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Oracle.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Oracle.port', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\006:\0041521\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Oracle.port_override', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.Oracle.tls_required', index=9,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15154,
  serialized_end=15673,
)


_POSTGRES = _descriptor.Descriptor(
  name='Postgres',
  full_name='v1.Postgres',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Postgres.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Postgres.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Postgres.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Postgres.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Postgres.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Postgres.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Postgres.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Postgres.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Postgres.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0045432\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_database', full_name='v1.Postgres.override_database', index=9,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15676,
  serialized_end=16202,
)


_AURORAPOSTGRES = _descriptor.Descriptor(
  name='AuroraPostgres',
  full_name='v1.AuroraPostgres',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AuroraPostgres.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.AuroraPostgres.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.AuroraPostgres.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.AuroraPostgres.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.AuroraPostgres.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.AuroraPostgres.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.AuroraPostgres.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.AuroraPostgres.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.AuroraPostgres.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0045432\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_database', full_name='v1.AuroraPostgres.override_database', index=9,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16205,
  serialized_end=16737,
)


_GREENPLUM = _descriptor.Descriptor(
  name='Greenplum',
  full_name='v1.Greenplum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Greenplum.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Greenplum.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Greenplum.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Greenplum.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Greenplum.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Greenplum.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Greenplum.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Greenplum.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Greenplum.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0045432\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_database', full_name='v1.Greenplum.override_database', index=9,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16740,
  serialized_end=17267,
)


_COCKROACH = _descriptor.Descriptor(
  name='Cockroach',
  full_name='v1.Cockroach',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Cockroach.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Cockroach.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Cockroach.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Cockroach.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Cockroach.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Cockroach.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Cockroach.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Cockroach.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Cockroach.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0045432\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_database', full_name='v1.Cockroach.override_database', index=9,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17270,
  serialized_end=17797,
)


_REDSHIFT = _descriptor.Descriptor(
  name='Redshift',
  full_name='v1.Redshift',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Redshift.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Redshift.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Redshift.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Redshift.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Redshift.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Redshift.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Redshift.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Redshift.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Redshift.port', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0045439\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_database', full_name='v1.Redshift.override_database', index=9,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17800,
  serialized_end=18326,
)


_PRESTO = _descriptor.Descriptor(
  name='Presto',
  full_name='v1.Presto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Presto.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Presto.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Presto.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Presto.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Presto.password', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Presto.database', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Presto.port_override', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Presto.port', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0048080\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Presto.username', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.Presto.tls_required', index=9,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18329,
  serialized_end=18848,
)


_RDP = _descriptor.Descriptor(
  name='RDP',
  full_name='v1.RDP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.RDP.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.RDP.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.RDP.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.RDP.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.RDP.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.RDP.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.RDP.port_override', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.RDP.port', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0043389\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18851,
  serialized_end=19253,
)


_REDIS = _descriptor.Descriptor(
  name='Redis',
  full_name='v1.Redis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Redis.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Redis.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Redis.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Redis.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Redis.port_override', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Redis.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Redis.port', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0046379\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19256,
  serialized_end=19605,
)


_ELASTICACHEREDIS = _descriptor.Descriptor(
  name='ElasticacheRedis',
  full_name='v1.ElasticacheRedis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.ElasticacheRedis.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.ElasticacheRedis.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.ElasticacheRedis.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.ElasticacheRedis.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.ElasticacheRedis.port_override', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.ElasticacheRedis.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.ElasticacheRedis.port', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0046379\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_required', full_name='v1.ElasticacheRedis.tls_required', index=7,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\004true\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19608,
  serialized_end=20036,
)


_SNOWFLAKE = _descriptor.Descriptor(
  name='Snowflake',
  full_name='v1.Snowflake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Snowflake.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Snowflake.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Snowflake.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Snowflake.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Snowflake.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Snowflake.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.Snowflake.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='v1.Snowflake.schema', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Snowflake.port_override', index=8,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20039,
  serialized_end=20495,
)


_SQLSERVER = _descriptor.Descriptor(
  name='SQLServer',
  full_name='v1.SQLServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.SQLServer.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.SQLServer.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.SQLServer.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.SQLServer.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.SQLServer.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.SQLServer.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database', full_name='v1.SQLServer.database', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.SQLServer.port_override', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='v1.SQLServer.schema', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.SQLServer.port', index=9,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0041433\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_database', full_name='v1.SQLServer.override_database', index=10,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20498,
  serialized_end=21078,
)


_SSH = _descriptor.Descriptor(
  name='SSH',
  full_name='v1.SSH',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.SSH.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.SSH.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.SSH.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.SSH.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.SSH.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.SSH.port', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\004:\00222\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='v1.SSH.public_key', index=6,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_forwarding', full_name='v1.SSH.port_forwarding', index=7,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\007:\005false\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21081,
  serialized_end=21495,
)


_SYBASE = _descriptor.Descriptor(
  name='Sybase',
  full_name='v1.Sybase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Sybase.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Sybase.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Sybase.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Sybase.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Sybase.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Sybase.port_override', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Sybase.port', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0042638\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Sybase.password', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21498,
  serialized_end=21903,
)


_SYBASEIQ = _descriptor.Descriptor(
  name='SybaseIQ',
  full_name='v1.SybaseIQ',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.SybaseIQ.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.SybaseIQ.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.SybaseIQ.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.SybaseIQ.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.SybaseIQ.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.SybaseIQ.port_override', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.SybaseIQ.port', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0042638\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.SybaseIQ.password', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21906,
  serialized_end=22313,
)


_TERADATA = _descriptor.Descriptor(
  name='Teradata',
  full_name='v1.Teradata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Teradata.id', index=0,
      number=32768, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Teradata.name', index=1,
      number=32769, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='healthy', full_name='v1.Teradata.healthy', index=2,
      number=32770, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\222A\002@\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='v1.Teradata.hostname', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='v1.Teradata.username', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v1.Teradata.password', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_override', full_name='v1.Teradata.port_override', index=6,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\001\362\370\263\007\005\330\363\263\007\000\222A\002@\000'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='v1.Teradata.port', index=7,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001\362\370\263\007\005\300\363\263\007\000\362\370\263\007\005\330\363\263\007\000\222A\006:\0041025\222A\002@\000'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22316,
  serialized_end=22723,
)

_RESOURCE.fields_by_name['athena'].message_type = _ATHENA
_RESOURCE.fields_by_name['big_query'].message_type = _BIGQUERY
_RESOURCE.fields_by_name['cassandra'].message_type = _CASSANDRA
_RESOURCE.fields_by_name['druid'].message_type = _DRUID
_RESOURCE.fields_by_name['dynamo_db'].message_type = _DYNAMODB
_RESOURCE.fields_by_name['amazon_es'].message_type = _AMAZONES
_RESOURCE.fields_by_name['elastic'].message_type = _ELASTIC
_RESOURCE.fields_by_name['http_basic_auth'].message_type = _HTTPBASICAUTH
_RESOURCE.fields_by_name['http_no_auth'].message_type = _HTTPNOAUTH
_RESOURCE.fields_by_name['http_auth'].message_type = _HTTPAUTH
_RESOURCE.fields_by_name['kubernetes'].message_type = _KUBERNETES
_RESOURCE.fields_by_name['kubernetes_basic_auth'].message_type = _KUBERNETESBASICAUTH
_RESOURCE.fields_by_name['kubernetes_service_account'].message_type = _KUBERNETESSERVICEACCOUNT
_RESOURCE.fields_by_name['amazon_eks'].message_type = _AMAZONEKS
_RESOURCE.fields_by_name['google_gke'].message_type = _GOOGLEGKE
_RESOURCE.fields_by_name['aks'].message_type = _AKS
_RESOURCE.fields_by_name['aks_basic_auth'].message_type = _AKSBASICAUTH
_RESOURCE.fields_by_name['aks_service_account'].message_type = _AKSSERVICEACCOUNT
_RESOURCE.fields_by_name['memcached'].message_type = _MEMCACHED
_RESOURCE.fields_by_name['mongo_legacy_host'].message_type = _MONGOLEGACYHOST
_RESOURCE.fields_by_name['mongo_legacy_replicaset'].message_type = _MONGOLEGACYREPLICASET
_RESOURCE.fields_by_name['mongo_host'].message_type = _MONGOHOST
_RESOURCE.fields_by_name['mongo_replica_set'].message_type = _MONGOREPLICASET
_RESOURCE.fields_by_name['mysql'].message_type = _MYSQL
_RESOURCE.fields_by_name['aurora_mysql'].message_type = _AURORAMYSQL
_RESOURCE.fields_by_name['clustrix'].message_type = _CLUSTRIX
_RESOURCE.fields_by_name['maria'].message_type = _MARIA
_RESOURCE.fields_by_name['memsql'].message_type = _MEMSQL
_RESOURCE.fields_by_name['oracle'].message_type = _ORACLE
_RESOURCE.fields_by_name['postgres'].message_type = _POSTGRES
_RESOURCE.fields_by_name['aurora_postgres'].message_type = _AURORAPOSTGRES
_RESOURCE.fields_by_name['greenplum'].message_type = _GREENPLUM
_RESOURCE.fields_by_name['cockroach'].message_type = _COCKROACH
_RESOURCE.fields_by_name['redshift'].message_type = _REDSHIFT
_RESOURCE.fields_by_name['presto'].message_type = _PRESTO
_RESOURCE.fields_by_name['rdp'].message_type = _RDP
_RESOURCE.fields_by_name['redis'].message_type = _REDIS
_RESOURCE.fields_by_name['elasticache_redis'].message_type = _ELASTICACHEREDIS
_RESOURCE.fields_by_name['snowflake'].message_type = _SNOWFLAKE
_RESOURCE.fields_by_name['sql_server'].message_type = _SQLSERVER
_RESOURCE.fields_by_name['ssh'].message_type = _SSH
_RESOURCE.fields_by_name['sybase'].message_type = _SYBASE
_RESOURCE.fields_by_name['sybase_iq'].message_type = _SYBASEIQ
_RESOURCE.fields_by_name['teradata'].message_type = _TERADATA
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['athena'])
_RESOURCE.fields_by_name['athena'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['big_query'])
_RESOURCE.fields_by_name['big_query'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['cassandra'])
_RESOURCE.fields_by_name['cassandra'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['druid'])
_RESOURCE.fields_by_name['druid'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['dynamo_db'])
_RESOURCE.fields_by_name['dynamo_db'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['amazon_es'])
_RESOURCE.fields_by_name['amazon_es'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['elastic'])
_RESOURCE.fields_by_name['elastic'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['http_basic_auth'])
_RESOURCE.fields_by_name['http_basic_auth'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['http_no_auth'])
_RESOURCE.fields_by_name['http_no_auth'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['http_auth'])
_RESOURCE.fields_by_name['http_auth'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['kubernetes'])
_RESOURCE.fields_by_name['kubernetes'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['kubernetes_basic_auth'])
_RESOURCE.fields_by_name['kubernetes_basic_auth'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['kubernetes_service_account'])
_RESOURCE.fields_by_name['kubernetes_service_account'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['amazon_eks'])
_RESOURCE.fields_by_name['amazon_eks'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['google_gke'])
_RESOURCE.fields_by_name['google_gke'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['aks'])
_RESOURCE.fields_by_name['aks'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['aks_basic_auth'])
_RESOURCE.fields_by_name['aks_basic_auth'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['aks_service_account'])
_RESOURCE.fields_by_name['aks_service_account'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['memcached'])
_RESOURCE.fields_by_name['memcached'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['mongo_legacy_host'])
_RESOURCE.fields_by_name['mongo_legacy_host'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['mongo_legacy_replicaset'])
_RESOURCE.fields_by_name['mongo_legacy_replicaset'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['mongo_host'])
_RESOURCE.fields_by_name['mongo_host'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['mongo_replica_set'])
_RESOURCE.fields_by_name['mongo_replica_set'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['mysql'])
_RESOURCE.fields_by_name['mysql'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['aurora_mysql'])
_RESOURCE.fields_by_name['aurora_mysql'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['clustrix'])
_RESOURCE.fields_by_name['clustrix'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['maria'])
_RESOURCE.fields_by_name['maria'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['memsql'])
_RESOURCE.fields_by_name['memsql'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['oracle'])
_RESOURCE.fields_by_name['oracle'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['postgres'])
_RESOURCE.fields_by_name['postgres'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['aurora_postgres'])
_RESOURCE.fields_by_name['aurora_postgres'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['greenplum'])
_RESOURCE.fields_by_name['greenplum'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['cockroach'])
_RESOURCE.fields_by_name['cockroach'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['redshift'])
_RESOURCE.fields_by_name['redshift'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['presto'])
_RESOURCE.fields_by_name['presto'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['rdp'])
_RESOURCE.fields_by_name['rdp'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['redis'])
_RESOURCE.fields_by_name['redis'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['elasticache_redis'])
_RESOURCE.fields_by_name['elasticache_redis'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['snowflake'])
_RESOURCE.fields_by_name['snowflake'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['sql_server'])
_RESOURCE.fields_by_name['sql_server'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['ssh'])
_RESOURCE.fields_by_name['ssh'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['sybase'])
_RESOURCE.fields_by_name['sybase'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['sybase_iq'])
_RESOURCE.fields_by_name['sybase_iq'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
_RESOURCE.oneofs_by_name['resource'].fields.append(
  _RESOURCE.fields_by_name['teradata'])
_RESOURCE.fields_by_name['teradata'].containing_oneof = _RESOURCE.oneofs_by_name['resource']
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.message_types_by_name['Athena'] = _ATHENA
DESCRIPTOR.message_types_by_name['BigQuery'] = _BIGQUERY
DESCRIPTOR.message_types_by_name['Cassandra'] = _CASSANDRA
DESCRIPTOR.message_types_by_name['Druid'] = _DRUID
DESCRIPTOR.message_types_by_name['DynamoDB'] = _DYNAMODB
DESCRIPTOR.message_types_by_name['AmazonES'] = _AMAZONES
DESCRIPTOR.message_types_by_name['Elastic'] = _ELASTIC
DESCRIPTOR.message_types_by_name['HTTPBasicAuth'] = _HTTPBASICAUTH
DESCRIPTOR.message_types_by_name['HTTPNoAuth'] = _HTTPNOAUTH
DESCRIPTOR.message_types_by_name['HTTPAuth'] = _HTTPAUTH
DESCRIPTOR.message_types_by_name['Kubernetes'] = _KUBERNETES
DESCRIPTOR.message_types_by_name['KubernetesBasicAuth'] = _KUBERNETESBASICAUTH
DESCRIPTOR.message_types_by_name['KubernetesServiceAccount'] = _KUBERNETESSERVICEACCOUNT
DESCRIPTOR.message_types_by_name['AmazonEKS'] = _AMAZONEKS
DESCRIPTOR.message_types_by_name['GoogleGKE'] = _GOOGLEGKE
DESCRIPTOR.message_types_by_name['AKS'] = _AKS
DESCRIPTOR.message_types_by_name['AKSBasicAuth'] = _AKSBASICAUTH
DESCRIPTOR.message_types_by_name['AKSServiceAccount'] = _AKSSERVICEACCOUNT
DESCRIPTOR.message_types_by_name['Memcached'] = _MEMCACHED
DESCRIPTOR.message_types_by_name['MongoLegacyHost'] = _MONGOLEGACYHOST
DESCRIPTOR.message_types_by_name['MongoLegacyReplicaset'] = _MONGOLEGACYREPLICASET
DESCRIPTOR.message_types_by_name['MongoHost'] = _MONGOHOST
DESCRIPTOR.message_types_by_name['MongoReplicaSet'] = _MONGOREPLICASET
DESCRIPTOR.message_types_by_name['Mysql'] = _MYSQL
DESCRIPTOR.message_types_by_name['AuroraMysql'] = _AURORAMYSQL
DESCRIPTOR.message_types_by_name['Clustrix'] = _CLUSTRIX
DESCRIPTOR.message_types_by_name['Maria'] = _MARIA
DESCRIPTOR.message_types_by_name['Memsql'] = _MEMSQL
DESCRIPTOR.message_types_by_name['Oracle'] = _ORACLE
DESCRIPTOR.message_types_by_name['Postgres'] = _POSTGRES
DESCRIPTOR.message_types_by_name['AuroraPostgres'] = _AURORAPOSTGRES
DESCRIPTOR.message_types_by_name['Greenplum'] = _GREENPLUM
DESCRIPTOR.message_types_by_name['Cockroach'] = _COCKROACH
DESCRIPTOR.message_types_by_name['Redshift'] = _REDSHIFT
DESCRIPTOR.message_types_by_name['Presto'] = _PRESTO
DESCRIPTOR.message_types_by_name['RDP'] = _RDP
DESCRIPTOR.message_types_by_name['Redis'] = _REDIS
DESCRIPTOR.message_types_by_name['ElasticacheRedis'] = _ELASTICACHEREDIS
DESCRIPTOR.message_types_by_name['Snowflake'] = _SNOWFLAKE
DESCRIPTOR.message_types_by_name['SQLServer'] = _SQLSERVER
DESCRIPTOR.message_types_by_name['SSH'] = _SSH
DESCRIPTOR.message_types_by_name['Sybase'] = _SYBASE
DESCRIPTOR.message_types_by_name['SybaseIQ'] = _SYBASEIQ
DESCRIPTOR.message_types_by_name['Teradata'] = _TERADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Resource)
  })
_sym_db.RegisterMessage(Resource)

Athena = _reflection.GeneratedProtocolMessageType('Athena', (_message.Message,), {
  'DESCRIPTOR' : _ATHENA,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Athena)
  })
_sym_db.RegisterMessage(Athena)

BigQuery = _reflection.GeneratedProtocolMessageType('BigQuery', (_message.Message,), {
  'DESCRIPTOR' : _BIGQUERY,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.BigQuery)
  })
_sym_db.RegisterMessage(BigQuery)

Cassandra = _reflection.GeneratedProtocolMessageType('Cassandra', (_message.Message,), {
  'DESCRIPTOR' : _CASSANDRA,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Cassandra)
  })
_sym_db.RegisterMessage(Cassandra)

Druid = _reflection.GeneratedProtocolMessageType('Druid', (_message.Message,), {
  'DESCRIPTOR' : _DRUID,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Druid)
  })
_sym_db.RegisterMessage(Druid)

DynamoDB = _reflection.GeneratedProtocolMessageType('DynamoDB', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMODB,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.DynamoDB)
  })
_sym_db.RegisterMessage(DynamoDB)

AmazonES = _reflection.GeneratedProtocolMessageType('AmazonES', (_message.Message,), {
  'DESCRIPTOR' : _AMAZONES,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.AmazonES)
  })
_sym_db.RegisterMessage(AmazonES)

Elastic = _reflection.GeneratedProtocolMessageType('Elastic', (_message.Message,), {
  'DESCRIPTOR' : _ELASTIC,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Elastic)
  })
_sym_db.RegisterMessage(Elastic)

HTTPBasicAuth = _reflection.GeneratedProtocolMessageType('HTTPBasicAuth', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBASICAUTH,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.HTTPBasicAuth)
  })
_sym_db.RegisterMessage(HTTPBasicAuth)

HTTPNoAuth = _reflection.GeneratedProtocolMessageType('HTTPNoAuth', (_message.Message,), {
  'DESCRIPTOR' : _HTTPNOAUTH,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.HTTPNoAuth)
  })
_sym_db.RegisterMessage(HTTPNoAuth)

HTTPAuth = _reflection.GeneratedProtocolMessageType('HTTPAuth', (_message.Message,), {
  'DESCRIPTOR' : _HTTPAUTH,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.HTTPAuth)
  })
_sym_db.RegisterMessage(HTTPAuth)

Kubernetes = _reflection.GeneratedProtocolMessageType('Kubernetes', (_message.Message,), {
  'DESCRIPTOR' : _KUBERNETES,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Kubernetes)
  })
_sym_db.RegisterMessage(Kubernetes)

KubernetesBasicAuth = _reflection.GeneratedProtocolMessageType('KubernetesBasicAuth', (_message.Message,), {
  'DESCRIPTOR' : _KUBERNETESBASICAUTH,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.KubernetesBasicAuth)
  })
_sym_db.RegisterMessage(KubernetesBasicAuth)

KubernetesServiceAccount = _reflection.GeneratedProtocolMessageType('KubernetesServiceAccount', (_message.Message,), {
  'DESCRIPTOR' : _KUBERNETESSERVICEACCOUNT,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.KubernetesServiceAccount)
  })
_sym_db.RegisterMessage(KubernetesServiceAccount)

AmazonEKS = _reflection.GeneratedProtocolMessageType('AmazonEKS', (_message.Message,), {
  'DESCRIPTOR' : _AMAZONEKS,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.AmazonEKS)
  })
_sym_db.RegisterMessage(AmazonEKS)

GoogleGKE = _reflection.GeneratedProtocolMessageType('GoogleGKE', (_message.Message,), {
  'DESCRIPTOR' : _GOOGLEGKE,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.GoogleGKE)
  })
_sym_db.RegisterMessage(GoogleGKE)

AKS = _reflection.GeneratedProtocolMessageType('AKS', (_message.Message,), {
  'DESCRIPTOR' : _AKS,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.AKS)
  })
_sym_db.RegisterMessage(AKS)

AKSBasicAuth = _reflection.GeneratedProtocolMessageType('AKSBasicAuth', (_message.Message,), {
  'DESCRIPTOR' : _AKSBASICAUTH,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.AKSBasicAuth)
  })
_sym_db.RegisterMessage(AKSBasicAuth)

AKSServiceAccount = _reflection.GeneratedProtocolMessageType('AKSServiceAccount', (_message.Message,), {
  'DESCRIPTOR' : _AKSSERVICEACCOUNT,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.AKSServiceAccount)
  })
_sym_db.RegisterMessage(AKSServiceAccount)

Memcached = _reflection.GeneratedProtocolMessageType('Memcached', (_message.Message,), {
  'DESCRIPTOR' : _MEMCACHED,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Memcached)
  })
_sym_db.RegisterMessage(Memcached)

MongoLegacyHost = _reflection.GeneratedProtocolMessageType('MongoLegacyHost', (_message.Message,), {
  'DESCRIPTOR' : _MONGOLEGACYHOST,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.MongoLegacyHost)
  })
_sym_db.RegisterMessage(MongoLegacyHost)

MongoLegacyReplicaset = _reflection.GeneratedProtocolMessageType('MongoLegacyReplicaset', (_message.Message,), {
  'DESCRIPTOR' : _MONGOLEGACYREPLICASET,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.MongoLegacyReplicaset)
  })
_sym_db.RegisterMessage(MongoLegacyReplicaset)

MongoHost = _reflection.GeneratedProtocolMessageType('MongoHost', (_message.Message,), {
  'DESCRIPTOR' : _MONGOHOST,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.MongoHost)
  })
_sym_db.RegisterMessage(MongoHost)

MongoReplicaSet = _reflection.GeneratedProtocolMessageType('MongoReplicaSet', (_message.Message,), {
  'DESCRIPTOR' : _MONGOREPLICASET,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.MongoReplicaSet)
  })
_sym_db.RegisterMessage(MongoReplicaSet)

Mysql = _reflection.GeneratedProtocolMessageType('Mysql', (_message.Message,), {
  'DESCRIPTOR' : _MYSQL,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Mysql)
  })
_sym_db.RegisterMessage(Mysql)

AuroraMysql = _reflection.GeneratedProtocolMessageType('AuroraMysql', (_message.Message,), {
  'DESCRIPTOR' : _AURORAMYSQL,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuroraMysql)
  })
_sym_db.RegisterMessage(AuroraMysql)

Clustrix = _reflection.GeneratedProtocolMessageType('Clustrix', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTRIX,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Clustrix)
  })
_sym_db.RegisterMessage(Clustrix)

Maria = _reflection.GeneratedProtocolMessageType('Maria', (_message.Message,), {
  'DESCRIPTOR' : _MARIA,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Maria)
  })
_sym_db.RegisterMessage(Maria)

Memsql = _reflection.GeneratedProtocolMessageType('Memsql', (_message.Message,), {
  'DESCRIPTOR' : _MEMSQL,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Memsql)
  })
_sym_db.RegisterMessage(Memsql)

Oracle = _reflection.GeneratedProtocolMessageType('Oracle', (_message.Message,), {
  'DESCRIPTOR' : _ORACLE,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Oracle)
  })
_sym_db.RegisterMessage(Oracle)

Postgres = _reflection.GeneratedProtocolMessageType('Postgres', (_message.Message,), {
  'DESCRIPTOR' : _POSTGRES,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Postgres)
  })
_sym_db.RegisterMessage(Postgres)

AuroraPostgres = _reflection.GeneratedProtocolMessageType('AuroraPostgres', (_message.Message,), {
  'DESCRIPTOR' : _AURORAPOSTGRES,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuroraPostgres)
  })
_sym_db.RegisterMessage(AuroraPostgres)

Greenplum = _reflection.GeneratedProtocolMessageType('Greenplum', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUM,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Greenplum)
  })
_sym_db.RegisterMessage(Greenplum)

Cockroach = _reflection.GeneratedProtocolMessageType('Cockroach', (_message.Message,), {
  'DESCRIPTOR' : _COCKROACH,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Cockroach)
  })
_sym_db.RegisterMessage(Cockroach)

Redshift = _reflection.GeneratedProtocolMessageType('Redshift', (_message.Message,), {
  'DESCRIPTOR' : _REDSHIFT,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Redshift)
  })
_sym_db.RegisterMessage(Redshift)

Presto = _reflection.GeneratedProtocolMessageType('Presto', (_message.Message,), {
  'DESCRIPTOR' : _PRESTO,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Presto)
  })
_sym_db.RegisterMessage(Presto)

RDP = _reflection.GeneratedProtocolMessageType('RDP', (_message.Message,), {
  'DESCRIPTOR' : _RDP,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.RDP)
  })
_sym_db.RegisterMessage(RDP)

Redis = _reflection.GeneratedProtocolMessageType('Redis', (_message.Message,), {
  'DESCRIPTOR' : _REDIS,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Redis)
  })
_sym_db.RegisterMessage(Redis)

ElasticacheRedis = _reflection.GeneratedProtocolMessageType('ElasticacheRedis', (_message.Message,), {
  'DESCRIPTOR' : _ELASTICACHEREDIS,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ElasticacheRedis)
  })
_sym_db.RegisterMessage(ElasticacheRedis)

Snowflake = _reflection.GeneratedProtocolMessageType('Snowflake', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKE,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Snowflake)
  })
_sym_db.RegisterMessage(Snowflake)

SQLServer = _reflection.GeneratedProtocolMessageType('SQLServer', (_message.Message,), {
  'DESCRIPTOR' : _SQLSERVER,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.SQLServer)
  })
_sym_db.RegisterMessage(SQLServer)

SSH = _reflection.GeneratedProtocolMessageType('SSH', (_message.Message,), {
  'DESCRIPTOR' : _SSH,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.SSH)
  })
_sym_db.RegisterMessage(SSH)

Sybase = _reflection.GeneratedProtocolMessageType('Sybase', (_message.Message,), {
  'DESCRIPTOR' : _SYBASE,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Sybase)
  })
_sym_db.RegisterMessage(Sybase)

SybaseIQ = _reflection.GeneratedProtocolMessageType('SybaseIQ', (_message.Message,), {
  'DESCRIPTOR' : _SYBASEIQ,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.SybaseIQ)
  })
_sym_db.RegisterMessage(SybaseIQ)

Teradata = _reflection.GeneratedProtocolMessageType('Teradata', (_message.Message,), {
  'DESCRIPTOR' : _TERADATA,
  '__module__' : 'drivers_pb2'
  # @@protoc_insertion_point(class_scope:v1.Teradata)
  })
_sym_db.RegisterMessage(Teradata)


DESCRIPTOR._options = None
_RESOURCE.oneofs_by_name['resource']._options = None
_RESOURCE._options = None
_ATHENA.fields_by_name['id']._options = None
_ATHENA.fields_by_name['name']._options = None
_ATHENA.fields_by_name['healthy']._options = None
_ATHENA.fields_by_name['access_key']._options = None
_ATHENA.fields_by_name['secret_access_key']._options = None
_ATHENA.fields_by_name['output']._options = None
_ATHENA.fields_by_name['port_override']._options = None
_ATHENA.fields_by_name['region']._options = None
_ATHENA._options = None
_BIGQUERY.fields_by_name['id']._options = None
_BIGQUERY.fields_by_name['name']._options = None
_BIGQUERY.fields_by_name['healthy']._options = None
_BIGQUERY.fields_by_name['private_key']._options = None
_BIGQUERY.fields_by_name['project']._options = None
_BIGQUERY.fields_by_name['port_override']._options = None
_BIGQUERY.fields_by_name['endpoint']._options = None
_BIGQUERY.fields_by_name['username']._options = None
_BIGQUERY._options = None
_CASSANDRA.fields_by_name['id']._options = None
_CASSANDRA.fields_by_name['name']._options = None
_CASSANDRA.fields_by_name['healthy']._options = None
_CASSANDRA.fields_by_name['hostname']._options = None
_CASSANDRA.fields_by_name['username']._options = None
_CASSANDRA.fields_by_name['password']._options = None
_CASSANDRA.fields_by_name['port_override']._options = None
_CASSANDRA.fields_by_name['port']._options = None
_CASSANDRA.fields_by_name['tls_required']._options = None
_CASSANDRA._options = None
_DRUID.fields_by_name['id']._options = None
_DRUID.fields_by_name['name']._options = None
_DRUID.fields_by_name['healthy']._options = None
_DRUID.fields_by_name['hostname']._options = None
_DRUID.fields_by_name['port_override']._options = None
_DRUID.fields_by_name['username']._options = None
_DRUID.fields_by_name['password']._options = None
_DRUID.fields_by_name['port']._options = None
_DRUID._options = None
_DYNAMODB.fields_by_name['id']._options = None
_DYNAMODB.fields_by_name['name']._options = None
_DYNAMODB.fields_by_name['healthy']._options = None
_DYNAMODB.fields_by_name['access_key']._options = None
_DYNAMODB.fields_by_name['secret_access_key']._options = None
_DYNAMODB.fields_by_name['region']._options = None
_DYNAMODB.fields_by_name['endpoint']._options = None
_DYNAMODB.fields_by_name['port_override']._options = None
_DYNAMODB._options = None
_AMAZONES.fields_by_name['id']._options = None
_AMAZONES.fields_by_name['name']._options = None
_AMAZONES.fields_by_name['healthy']._options = None
_AMAZONES.fields_by_name['region']._options = None
_AMAZONES.fields_by_name['secret_access_key']._options = None
_AMAZONES.fields_by_name['endpoint']._options = None
_AMAZONES.fields_by_name['access_key']._options = None
_AMAZONES.fields_by_name['port_override']._options = None
_AMAZONES._options = None
_ELASTIC.fields_by_name['id']._options = None
_ELASTIC.fields_by_name['name']._options = None
_ELASTIC.fields_by_name['healthy']._options = None
_ELASTIC.fields_by_name['hostname']._options = None
_ELASTIC.fields_by_name['username']._options = None
_ELASTIC.fields_by_name['password']._options = None
_ELASTIC.fields_by_name['port_override']._options = None
_ELASTIC.fields_by_name['port']._options = None
_ELASTIC.fields_by_name['tls_required']._options = None
_ELASTIC._options = None
_HTTPBASICAUTH.fields_by_name['id']._options = None
_HTTPBASICAUTH.fields_by_name['name']._options = None
_HTTPBASICAUTH.fields_by_name['healthy']._options = None
_HTTPBASICAUTH.fields_by_name['url']._options = None
_HTTPBASICAUTH.fields_by_name['healthcheck_path']._options = None
_HTTPBASICAUTH.fields_by_name['username']._options = None
_HTTPBASICAUTH.fields_by_name['password']._options = None
_HTTPBASICAUTH.fields_by_name['headers_blacklist']._options = None
_HTTPBASICAUTH.fields_by_name['default_path']._options = None
_HTTPBASICAUTH.fields_by_name['subdomain']._options = None
_HTTPBASICAUTH._options = None
_HTTPNOAUTH.fields_by_name['id']._options = None
_HTTPNOAUTH.fields_by_name['name']._options = None
_HTTPNOAUTH.fields_by_name['healthy']._options = None
_HTTPNOAUTH.fields_by_name['url']._options = None
_HTTPNOAUTH.fields_by_name['healthcheck_path']._options = None
_HTTPNOAUTH.fields_by_name['headers_blacklist']._options = None
_HTTPNOAUTH.fields_by_name['default_path']._options = None
_HTTPNOAUTH.fields_by_name['subdomain']._options = None
_HTTPNOAUTH._options = None
_HTTPAUTH.fields_by_name['id']._options = None
_HTTPAUTH.fields_by_name['name']._options = None
_HTTPAUTH.fields_by_name['healthy']._options = None
_HTTPAUTH.fields_by_name['url']._options = None
_HTTPAUTH.fields_by_name['healthcheck_path']._options = None
_HTTPAUTH.fields_by_name['auth_header']._options = None
_HTTPAUTH.fields_by_name['headers_blacklist']._options = None
_HTTPAUTH.fields_by_name['default_path']._options = None
_HTTPAUTH.fields_by_name['subdomain']._options = None
_HTTPAUTH._options = None
_KUBERNETES.fields_by_name['id']._options = None
_KUBERNETES.fields_by_name['name']._options = None
_KUBERNETES.fields_by_name['healthy']._options = None
_KUBERNETES.fields_by_name['hostname']._options = None
_KUBERNETES.fields_by_name['port']._options = None
_KUBERNETES.fields_by_name['certificate_authority']._options = None
_KUBERNETES.fields_by_name['certificate_authority_filename']._options = None
_KUBERNETES.fields_by_name['client_certificate']._options = None
_KUBERNETES.fields_by_name['client_certificate_filename']._options = None
_KUBERNETES.fields_by_name['client_key']._options = None
_KUBERNETES.fields_by_name['client_key_filename']._options = None
_KUBERNETES._options = None
_KUBERNETESBASICAUTH.fields_by_name['id']._options = None
_KUBERNETESBASICAUTH.fields_by_name['name']._options = None
_KUBERNETESBASICAUTH.fields_by_name['healthy']._options = None
_KUBERNETESBASICAUTH.fields_by_name['hostname']._options = None
_KUBERNETESBASICAUTH.fields_by_name['port']._options = None
_KUBERNETESBASICAUTH.fields_by_name['username']._options = None
_KUBERNETESBASICAUTH.fields_by_name['password']._options = None
_KUBERNETESBASICAUTH._options = None
_KUBERNETESSERVICEACCOUNT.fields_by_name['id']._options = None
_KUBERNETESSERVICEACCOUNT.fields_by_name['name']._options = None
_KUBERNETESSERVICEACCOUNT.fields_by_name['healthy']._options = None
_KUBERNETESSERVICEACCOUNT.fields_by_name['hostname']._options = None
_KUBERNETESSERVICEACCOUNT.fields_by_name['port']._options = None
_KUBERNETESSERVICEACCOUNT.fields_by_name['token']._options = None
_KUBERNETESSERVICEACCOUNT._options = None
_AMAZONEKS.fields_by_name['id']._options = None
_AMAZONEKS.fields_by_name['name']._options = None
_AMAZONEKS.fields_by_name['healthy']._options = None
_AMAZONEKS.fields_by_name['endpoint']._options = None
_AMAZONEKS.fields_by_name['access_key']._options = None
_AMAZONEKS.fields_by_name['secret_access_key']._options = None
_AMAZONEKS.fields_by_name['certificate_authority']._options = None
_AMAZONEKS.fields_by_name['certificate_authority_filename']._options = None
_AMAZONEKS.fields_by_name['region']._options = None
_AMAZONEKS.fields_by_name['cluster_name']._options = None
_AMAZONEKS.fields_by_name['role_arn']._options = None
_AMAZONEKS._options = None
_GOOGLEGKE.fields_by_name['id']._options = None
_GOOGLEGKE.fields_by_name['name']._options = None
_GOOGLEGKE.fields_by_name['healthy']._options = None
_GOOGLEGKE.fields_by_name['endpoint']._options = None
_GOOGLEGKE.fields_by_name['certificate_authority']._options = None
_GOOGLEGKE.fields_by_name['certificate_authority_filename']._options = None
_GOOGLEGKE.fields_by_name['service_account_key']._options = None
_GOOGLEGKE.fields_by_name['service_account_key_filename']._options = None
_GOOGLEGKE._options = None
_AKS.fields_by_name['id']._options = None
_AKS.fields_by_name['name']._options = None
_AKS.fields_by_name['healthy']._options = None
_AKS.fields_by_name['hostname']._options = None
_AKS.fields_by_name['port']._options = None
_AKS.fields_by_name['certificate_authority']._options = None
_AKS.fields_by_name['certificate_authority_filename']._options = None
_AKS.fields_by_name['client_certificate']._options = None
_AKS.fields_by_name['client_certificate_filename']._options = None
_AKS.fields_by_name['client_key']._options = None
_AKS.fields_by_name['client_key_filename']._options = None
_AKS._options = None
_AKSBASICAUTH.fields_by_name['id']._options = None
_AKSBASICAUTH.fields_by_name['name']._options = None
_AKSBASICAUTH.fields_by_name['healthy']._options = None
_AKSBASICAUTH.fields_by_name['hostname']._options = None
_AKSBASICAUTH.fields_by_name['port']._options = None
_AKSBASICAUTH.fields_by_name['username']._options = None
_AKSBASICAUTH.fields_by_name['password']._options = None
_AKSBASICAUTH._options = None
_AKSSERVICEACCOUNT.fields_by_name['id']._options = None
_AKSSERVICEACCOUNT.fields_by_name['name']._options = None
_AKSSERVICEACCOUNT.fields_by_name['healthy']._options = None
_AKSSERVICEACCOUNT.fields_by_name['hostname']._options = None
_AKSSERVICEACCOUNT.fields_by_name['port']._options = None
_AKSSERVICEACCOUNT.fields_by_name['token']._options = None
_AKSSERVICEACCOUNT._options = None
_MEMCACHED.fields_by_name['id']._options = None
_MEMCACHED.fields_by_name['name']._options = None
_MEMCACHED.fields_by_name['healthy']._options = None
_MEMCACHED.fields_by_name['hostname']._options = None
_MEMCACHED.fields_by_name['port_override']._options = None
_MEMCACHED.fields_by_name['port']._options = None
_MEMCACHED._options = None
_MONGOLEGACYHOST.fields_by_name['id']._options = None
_MONGOLEGACYHOST.fields_by_name['name']._options = None
_MONGOLEGACYHOST.fields_by_name['healthy']._options = None
_MONGOLEGACYHOST.fields_by_name['hostname']._options = None
_MONGOLEGACYHOST.fields_by_name['auth_database']._options = None
_MONGOLEGACYHOST.fields_by_name['port_override']._options = None
_MONGOLEGACYHOST.fields_by_name['username']._options = None
_MONGOLEGACYHOST.fields_by_name['password']._options = None
_MONGOLEGACYHOST.fields_by_name['port']._options = None
_MONGOLEGACYHOST.fields_by_name['replica_set']._options = None
_MONGOLEGACYHOST.fields_by_name['tls_required']._options = None
_MONGOLEGACYHOST._options = None
_MONGOLEGACYREPLICASET.fields_by_name['id']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['name']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['healthy']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['hostname']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['auth_database']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['port_override']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['username']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['password']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['port']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['replica_set']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['connect_to_replica']._options = None
_MONGOLEGACYREPLICASET.fields_by_name['tls_required']._options = None
_MONGOLEGACYREPLICASET._options = None
_MONGOHOST.fields_by_name['id']._options = None
_MONGOHOST.fields_by_name['name']._options = None
_MONGOHOST.fields_by_name['healthy']._options = None
_MONGOHOST.fields_by_name['hostname']._options = None
_MONGOHOST.fields_by_name['auth_database']._options = None
_MONGOHOST.fields_by_name['port_override']._options = None
_MONGOHOST.fields_by_name['username']._options = None
_MONGOHOST.fields_by_name['password']._options = None
_MONGOHOST.fields_by_name['port']._options = None
_MONGOHOST.fields_by_name['tls_required']._options = None
_MONGOHOST._options = None
_MONGOREPLICASET.fields_by_name['id']._options = None
_MONGOREPLICASET.fields_by_name['name']._options = None
_MONGOREPLICASET.fields_by_name['healthy']._options = None
_MONGOREPLICASET.fields_by_name['hostname']._options = None
_MONGOREPLICASET.fields_by_name['auth_database']._options = None
_MONGOREPLICASET.fields_by_name['port_override']._options = None
_MONGOREPLICASET.fields_by_name['username']._options = None
_MONGOREPLICASET.fields_by_name['password']._options = None
_MONGOREPLICASET.fields_by_name['port']._options = None
_MONGOREPLICASET.fields_by_name['replica_set']._options = None
_MONGOREPLICASET.fields_by_name['connect_to_replica']._options = None
_MONGOREPLICASET.fields_by_name['tls_required']._options = None
_MONGOREPLICASET._options = None
_MYSQL.fields_by_name['id']._options = None
_MYSQL.fields_by_name['name']._options = None
_MYSQL.fields_by_name['healthy']._options = None
_MYSQL.fields_by_name['hostname']._options = None
_MYSQL.fields_by_name['username']._options = None
_MYSQL.fields_by_name['password']._options = None
_MYSQL.fields_by_name['database']._options = None
_MYSQL.fields_by_name['port_override']._options = None
_MYSQL.fields_by_name['port']._options = None
_MYSQL._options = None
_AURORAMYSQL.fields_by_name['id']._options = None
_AURORAMYSQL.fields_by_name['name']._options = None
_AURORAMYSQL.fields_by_name['healthy']._options = None
_AURORAMYSQL.fields_by_name['hostname']._options = None
_AURORAMYSQL.fields_by_name['username']._options = None
_AURORAMYSQL.fields_by_name['password']._options = None
_AURORAMYSQL.fields_by_name['database']._options = None
_AURORAMYSQL.fields_by_name['port_override']._options = None
_AURORAMYSQL.fields_by_name['port']._options = None
_AURORAMYSQL._options = None
_CLUSTRIX.fields_by_name['id']._options = None
_CLUSTRIX.fields_by_name['name']._options = None
_CLUSTRIX.fields_by_name['healthy']._options = None
_CLUSTRIX.fields_by_name['hostname']._options = None
_CLUSTRIX.fields_by_name['username']._options = None
_CLUSTRIX.fields_by_name['password']._options = None
_CLUSTRIX.fields_by_name['database']._options = None
_CLUSTRIX.fields_by_name['port_override']._options = None
_CLUSTRIX.fields_by_name['port']._options = None
_CLUSTRIX._options = None
_MARIA.fields_by_name['id']._options = None
_MARIA.fields_by_name['name']._options = None
_MARIA.fields_by_name['healthy']._options = None
_MARIA.fields_by_name['hostname']._options = None
_MARIA.fields_by_name['username']._options = None
_MARIA.fields_by_name['password']._options = None
_MARIA.fields_by_name['database']._options = None
_MARIA.fields_by_name['port_override']._options = None
_MARIA.fields_by_name['port']._options = None
_MARIA._options = None
_MEMSQL.fields_by_name['id']._options = None
_MEMSQL.fields_by_name['name']._options = None
_MEMSQL.fields_by_name['healthy']._options = None
_MEMSQL.fields_by_name['hostname']._options = None
_MEMSQL.fields_by_name['username']._options = None
_MEMSQL.fields_by_name['password']._options = None
_MEMSQL.fields_by_name['database']._options = None
_MEMSQL.fields_by_name['port_override']._options = None
_MEMSQL.fields_by_name['port']._options = None
_MEMSQL._options = None
_ORACLE.fields_by_name['id']._options = None
_ORACLE.fields_by_name['name']._options = None
_ORACLE.fields_by_name['healthy']._options = None
_ORACLE.fields_by_name['hostname']._options = None
_ORACLE.fields_by_name['username']._options = None
_ORACLE.fields_by_name['password']._options = None
_ORACLE.fields_by_name['database']._options = None
_ORACLE.fields_by_name['port']._options = None
_ORACLE.fields_by_name['port_override']._options = None
_ORACLE.fields_by_name['tls_required']._options = None
_ORACLE._options = None
_POSTGRES.fields_by_name['id']._options = None
_POSTGRES.fields_by_name['name']._options = None
_POSTGRES.fields_by_name['healthy']._options = None
_POSTGRES.fields_by_name['hostname']._options = None
_POSTGRES.fields_by_name['username']._options = None
_POSTGRES.fields_by_name['password']._options = None
_POSTGRES.fields_by_name['database']._options = None
_POSTGRES.fields_by_name['port_override']._options = None
_POSTGRES.fields_by_name['port']._options = None
_POSTGRES.fields_by_name['override_database']._options = None
_POSTGRES._options = None
_AURORAPOSTGRES.fields_by_name['id']._options = None
_AURORAPOSTGRES.fields_by_name['name']._options = None
_AURORAPOSTGRES.fields_by_name['healthy']._options = None
_AURORAPOSTGRES.fields_by_name['hostname']._options = None
_AURORAPOSTGRES.fields_by_name['username']._options = None
_AURORAPOSTGRES.fields_by_name['password']._options = None
_AURORAPOSTGRES.fields_by_name['database']._options = None
_AURORAPOSTGRES.fields_by_name['port_override']._options = None
_AURORAPOSTGRES.fields_by_name['port']._options = None
_AURORAPOSTGRES.fields_by_name['override_database']._options = None
_AURORAPOSTGRES._options = None
_GREENPLUM.fields_by_name['id']._options = None
_GREENPLUM.fields_by_name['name']._options = None
_GREENPLUM.fields_by_name['healthy']._options = None
_GREENPLUM.fields_by_name['hostname']._options = None
_GREENPLUM.fields_by_name['username']._options = None
_GREENPLUM.fields_by_name['password']._options = None
_GREENPLUM.fields_by_name['database']._options = None
_GREENPLUM.fields_by_name['port_override']._options = None
_GREENPLUM.fields_by_name['port']._options = None
_GREENPLUM.fields_by_name['override_database']._options = None
_GREENPLUM._options = None
_COCKROACH.fields_by_name['id']._options = None
_COCKROACH.fields_by_name['name']._options = None
_COCKROACH.fields_by_name['healthy']._options = None
_COCKROACH.fields_by_name['hostname']._options = None
_COCKROACH.fields_by_name['username']._options = None
_COCKROACH.fields_by_name['password']._options = None
_COCKROACH.fields_by_name['database']._options = None
_COCKROACH.fields_by_name['port_override']._options = None
_COCKROACH.fields_by_name['port']._options = None
_COCKROACH.fields_by_name['override_database']._options = None
_COCKROACH._options = None
_REDSHIFT.fields_by_name['id']._options = None
_REDSHIFT.fields_by_name['name']._options = None
_REDSHIFT.fields_by_name['healthy']._options = None
_REDSHIFT.fields_by_name['hostname']._options = None
_REDSHIFT.fields_by_name['username']._options = None
_REDSHIFT.fields_by_name['password']._options = None
_REDSHIFT.fields_by_name['database']._options = None
_REDSHIFT.fields_by_name['port_override']._options = None
_REDSHIFT.fields_by_name['port']._options = None
_REDSHIFT.fields_by_name['override_database']._options = None
_REDSHIFT._options = None
_PRESTO.fields_by_name['id']._options = None
_PRESTO.fields_by_name['name']._options = None
_PRESTO.fields_by_name['healthy']._options = None
_PRESTO.fields_by_name['hostname']._options = None
_PRESTO.fields_by_name['password']._options = None
_PRESTO.fields_by_name['database']._options = None
_PRESTO.fields_by_name['port_override']._options = None
_PRESTO.fields_by_name['port']._options = None
_PRESTO.fields_by_name['username']._options = None
_PRESTO.fields_by_name['tls_required']._options = None
_PRESTO._options = None
_RDP.fields_by_name['id']._options = None
_RDP.fields_by_name['name']._options = None
_RDP.fields_by_name['healthy']._options = None
_RDP.fields_by_name['hostname']._options = None
_RDP.fields_by_name['username']._options = None
_RDP.fields_by_name['password']._options = None
_RDP.fields_by_name['port_override']._options = None
_RDP.fields_by_name['port']._options = None
_RDP._options = None
_REDIS.fields_by_name['id']._options = None
_REDIS.fields_by_name['name']._options = None
_REDIS.fields_by_name['healthy']._options = None
_REDIS.fields_by_name['hostname']._options = None
_REDIS.fields_by_name['port_override']._options = None
_REDIS.fields_by_name['password']._options = None
_REDIS.fields_by_name['port']._options = None
_REDIS._options = None
_ELASTICACHEREDIS.fields_by_name['id']._options = None
_ELASTICACHEREDIS.fields_by_name['name']._options = None
_ELASTICACHEREDIS.fields_by_name['healthy']._options = None
_ELASTICACHEREDIS.fields_by_name['hostname']._options = None
_ELASTICACHEREDIS.fields_by_name['port_override']._options = None
_ELASTICACHEREDIS.fields_by_name['password']._options = None
_ELASTICACHEREDIS.fields_by_name['port']._options = None
_ELASTICACHEREDIS.fields_by_name['tls_required']._options = None
_ELASTICACHEREDIS._options = None
_SNOWFLAKE.fields_by_name['id']._options = None
_SNOWFLAKE.fields_by_name['name']._options = None
_SNOWFLAKE.fields_by_name['healthy']._options = None
_SNOWFLAKE.fields_by_name['hostname']._options = None
_SNOWFLAKE.fields_by_name['username']._options = None
_SNOWFLAKE.fields_by_name['password']._options = None
_SNOWFLAKE.fields_by_name['database']._options = None
_SNOWFLAKE.fields_by_name['schema']._options = None
_SNOWFLAKE.fields_by_name['port_override']._options = None
_SNOWFLAKE._options = None
_SQLSERVER.fields_by_name['id']._options = None
_SQLSERVER.fields_by_name['name']._options = None
_SQLSERVER.fields_by_name['healthy']._options = None
_SQLSERVER.fields_by_name['hostname']._options = None
_SQLSERVER.fields_by_name['username']._options = None
_SQLSERVER.fields_by_name['password']._options = None
_SQLSERVER.fields_by_name['database']._options = None
_SQLSERVER.fields_by_name['port_override']._options = None
_SQLSERVER.fields_by_name['schema']._options = None
_SQLSERVER.fields_by_name['port']._options = None
_SQLSERVER.fields_by_name['override_database']._options = None
_SQLSERVER._options = None
_SSH.fields_by_name['id']._options = None
_SSH.fields_by_name['name']._options = None
_SSH.fields_by_name['healthy']._options = None
_SSH.fields_by_name['hostname']._options = None
_SSH.fields_by_name['username']._options = None
_SSH.fields_by_name['port']._options = None
_SSH.fields_by_name['public_key']._options = None
_SSH.fields_by_name['port_forwarding']._options = None
_SSH._options = None
_SYBASE.fields_by_name['id']._options = None
_SYBASE.fields_by_name['name']._options = None
_SYBASE.fields_by_name['healthy']._options = None
_SYBASE.fields_by_name['hostname']._options = None
_SYBASE.fields_by_name['username']._options = None
_SYBASE.fields_by_name['port_override']._options = None
_SYBASE.fields_by_name['port']._options = None
_SYBASE.fields_by_name['password']._options = None
_SYBASE._options = None
_SYBASEIQ.fields_by_name['id']._options = None
_SYBASEIQ.fields_by_name['name']._options = None
_SYBASEIQ.fields_by_name['healthy']._options = None
_SYBASEIQ.fields_by_name['hostname']._options = None
_SYBASEIQ.fields_by_name['username']._options = None
_SYBASEIQ.fields_by_name['port_override']._options = None
_SYBASEIQ.fields_by_name['port']._options = None
_SYBASEIQ.fields_by_name['password']._options = None
_SYBASEIQ._options = None
_TERADATA.fields_by_name['id']._options = None
_TERADATA.fields_by_name['name']._options = None
_TERADATA.fields_by_name['healthy']._options = None
_TERADATA.fields_by_name['hostname']._options = None
_TERADATA.fields_by_name['username']._options = None
_TERADATA.fields_by_name['password']._options = None
_TERADATA.fields_by_name['port_override']._options = None
_TERADATA.fields_by_name['port']._options = None
_TERADATA._options = None
# @@protoc_insertion_point(module_scope)
